pub enum ValueKind {
Adt,
RawPtr,
Ref,
Tuple,
SpecialPtr,
}Expand description
Represents different kinds of types for alias analysis purposes. This is a wrapper of rustc_middle::ty::TyKind, except that treat some types as special cases;
Variants
Adt
Algebraic Data Type (structs, enums, basic composite types).
RawPtr
Raw pointer type, e.g., *const T or *mut T.
Ref
Reference type, e.g., &T or &mut T.
Tuple
Tuple type, e.g., (T1, T2, ...).
SpecialPtr
Special cases such as RefCell, Rc, etc., which need to be treated differently.